==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/IAM/GetAccountPasswordPolicy.pm <==

package Paws::IAM::GetAccountPasswordPolicy {
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetAccountPasswordPolicy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetAccountPasswordPolicyResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetAccountPasswordPolicyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetAccountPasswordPolicy - Arguments for method GetAccountPasswordPolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetAccountPasswordPolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetAccountPasswordPolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetAccountPasswordPolicy.

As an example:

  $service_obj->GetAccountPasswordPolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for GetAccountPasswordPolicy in Paws::IAM

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.09.tar.gz: Paws-0.09/lib/Paws/IAM/GetAccountPasswordPolicy.pm <==

package Paws::IAM::GetAccountPasswordPolicy {
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetAccountPasswordPolicy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetAccountPasswordPolicyResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetAccountPasswordPolicyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetAccountPasswordPolicy - Arguments for method GetAccountPasswordPolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetAccountPasswordPolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetAccountPasswordPolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetAccountPasswordPolicy.

As an example:

  $service_obj->GetAccountPasswordPolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetAccountPasswordPolicy in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
